LSMTool: the LOFAR Sky Model Tool
=================================

LSMTool is a Python package which allows for the manipulation of LOFAR sky
models in the ``makesourcedb`` format.
Please refer to the project's
`README <https://git.astron.nl/RD/LSMTool/#downloading-and-installing>`_
file for instructions on downloading and installing LSMTool.

Contents
========

.. toctree::
   :maxdepth: 3

   overview.rst
   api/lsmtool

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

